@@ -40,7 +40,19 @@ var NAVTREE =
     ] ],
     [ "CHANGELOG", "changelog.html", null ],
     [ "README.md", "readme.html", null ],
-    [ "Usage", "usage.html", "usage" ],
+    [ "Usage", "usage.html", [
+      [ "Important Data Types", "usage.html#usage_types", [
+        [ "Contexts", "usage.html#usage_ctxs", null ],
+        [ "Interfaces", "usage.html#usage_ifaces", null ]
+      ] ],
+      [ "Features", "usage.html#usage_features", null ],
+      [ "Initialization", "usage.html#usage_init", null ],
+      [ "Error Handling", "usage.html#usage_errors", null ],
+      [ "Decoding", "usage_decode.html", [
+        [ "Frame Iterator Based Decoding", "usage_decode.html#usage_frame_iter", null ]
+      ] ],
+      [ "Encoding", "usage_encode.html", null ]
+    ] ],
     [ "AV1 DECODER GUIDE", "decoder_guide.html", null ],
     [ "AV1 ENCODER GUIDE", "encoder_guide.html", [
       [ "Introduction", "encoder_guide.html#architecture_introduction", [
@@ -104,7 +116,24 @@ var NAVTREE =
         ] ]
       ] ]
     ] ],
-    [ "Sample Code", "samples.html", "samples" ],
+    [ "Sample Code", "samples.html", [
+      [ "decode_to_md5", "example_decode_to_md5.html", null ],
+      [ "decode_with_drops", "example_decode_with_drops.html", null ],
+      [ "simple_decoder", "example_simple_decoder.html", null ],
+      [ "lossless_encoder", "example_lossless_encoder.html", null ],
+      [ "set_maps", "example_set_maps.html", null ],
+      [ "simple_encoder", "example_simple_encoder.html", null ],
+      [ "twopass_encoder", "example_twopass_encoder.html", null ],
+      [ "scalable_encoder", "example_scalable_encoder.html", null ],
+      [ "svc_encoder_rtc", "example_svc_encoder_rtc.html", null ],
+      [ "aom_cx_set_ref", "example_aom_cx_set_ref.html", null ],
+      [ "lightfield_encoder", "example_lightfield_encoder.html", null ],
+      [ "lightfield_tile_list_decoder", "example_lightfield_tile_list_decoder.html", null ],
+      [ "lightfield_decoder", "example_lightfield_decoder.html", null ],
+      [ "lightfield_bitstream_parsing", "example_lightfield_bitstream_parsing.html", null ],
+      [ "aomdec", "example_aomdec.html", null ],
+      [ "aomenc", "example_aomenc.html", null ]
+    ] ],
     [ "README.md", "LREADME.html", [
       [ "AV1 Codec Library", "LREADME.html#autotoc_md0", [
         [ "Contents", "LREADME.html#autotoc_md1", null ],
@@ -154,7 +183,7 @@ var NAVTREE =
       ] ]
     ] ],
     [ "Deprecated List", "deprecated.html", null ],
-    [ "Modules", "modules.html", "modules" ],
+    [ "Topics", "topics.html", "topics" ],
     [ "Data Structures", "annotated.html", [
       [ "Data Structures", "annotated.html", "annotated_dup" ],
       [ "Data Fields", "functions.html", [
@@ -180,16 +209,16 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "LREADME.html",
-"encoder_guide.html#architecture_enc_intra_modes",
-"group__aom__encoder.html#ga790f05ad7832f2614a13fd60bd3430fe",
-"group__codec.html#ggac34a24f7c6c0fef7518aed0da4425f61a5abd24080a18d4f7e33217d93a73e968",
-"group__transform__search.html#ga96f1b74712969cad39e8759642341ea3",
-"structAV1__COMP.html#aa3403fc90f89d25b1b18ed11e14384c1",
-"structCompoundTypeCfg.html#a6f8296d512aa11644fd517139f16819a",
-"structMB__MODE__INFO__EXT__FRAME.html#a430fd9e49f38ceae3aec0ec8f80bd700",
-"structSuperBlockEnc.html#a11ec5173d2e6f78607276a6770fe180f",
-"structaom__image.html#ab986419a1f0fff93a2dc505f47194988",
-"structmacroblock.html#a764c3f23fd2e1d581a1265bad933c196"
+"encoder_guide.html#architecture_enc_gf_structure",
+"group__aom__encoder.html#ga758649aa6cd9fefb15ad888489884a38",
+"group__codec.html#ggaaae61e0f8663e6137f1e228757248e7ca7cbf0a1ff28bf7c460f6d86d63b30842",
+"group__tpl__modelling.html#gacb25270842c5ab92d1d90a211df955e5",
+"structAV1__COMP.html#a81e0bda4dd2dff128613be4c1cd186fb",
+"structCommonTileParams.html#a68c8e416df2344d1338ebc6959651b0d",
+"structMB__MODE__INFO.html#a8552e37deea204df2caff7aa688f8ccf",
+"structRestorationUnitInfo.html#ac0f1e8bf804a5db5a6b38027e9bdb4f4",
+"structaom__ext__part__funcs.html#a00b5dea45726cf43a0407cbd7d09b907",
+"structmacroblock.html#a22c8a3380f06cf7061181e1ba5de5d5a"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
