@@ -1,5 +1,6 @@
 var NAVTREEINDEX6 =
 {
+"structCommonTileParams.html#a68c8e416df2344d1338ebc6959651b0d":[13,0,58,16],
 "structCommonTileParams.html#a8842e296add2a242e4aaf0fcae574f9b":[13,0,58,0],
 "structCommonTileParams.html#a9d06ed0c420a1571838df00f89603ba7":[13,0,58,3],
 "structCommonTileParams.html#aa268beca2c5cb66be43cf6f9ab3d81fd":[13,0,58,17],
@@ -248,6 +249,5 @@ var NAVTREEINDEX6 =
 "structMB__MODE__INFO.html#a78e61449b1aaf129f0706e876eaa252f":[13,0,94,19],
 "structMB__MODE__INFO.html#a79704bc4fbe9b3e431e874f7353d1d1e":[13,0,94,25],
 "structMB__MODE__INFO.html#a80b6f65a3361030cde834acad9b38f21":[13,0,94,18],
-"structMB__MODE__INFO.html#a826e27476434a97d326cda91263c69ea":[13,0,94,27],
-"structMB__MODE__INFO.html#a8552e37deea204df2caff7aa688f8ccf":[13,0,94,31]
+"structMB__MODE__INFO.html#a826e27476434a97d326cda91263c69ea":[13,0,94,27]
 };
